@@ -1811,4 +1811,7 @@ Issues in 1.02-1.04
      xs_sched_getaffinity keeps segfaulting (x4)
   4. getNumCpus_from_Win32API_System_Info: garbage result on WOW64 systems
 
+Issues in 1.06
+
+  Unreliable on systems with more than 32 cores (RT#94560)
 
