@@ -19,7 +19,7 @@ use warnings;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(CONFIG CONFIG_module);
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
-our $VERSION = '0.76';
+our $VERSION = '0.77';
 
 our (%CONFIG, $IS_TEST, $IS_TEST_CONFIG, %SIGNO, $CONFIG_FILE);
 
@@ -293,14 +293,24 @@ Dynamic configuration signals:
     };
     $XSIG{$config_sig[2]}[1] = sub { 
 	$DB::single = 1;
-	$Forks::Super::MAX_PROC++; 
-	print STDERR "MAX_PROC changed to $Forks::Super::MAX_PROC\n";
+        if (!ref($Forks::Super::MAX_PROC)) {
+            $Forks::Super::MAX_PROC++;
+            print STDERR "MAX_PROC changed to $Forks::Super::MAX_PROC\n";
+        } else {
+            print STDERR
+                "\$Forks::Super::MAX_PROC is a coderef. Unable to increment\n";
+        }
     };
     $XSIG{$config_sig[3]}[1] = sub {
 	$DB::single = 1;
-	$Forks::Super::MAX_PROC--; 
-	$Forks::Super::MAX_PROC ||= 1;
-	print STDERR "MAX_PROC changed to $Forks::Super::MAX_PROC\n";
+        if (!ref($Forks::Super::MAX_PROC)) {
+            $Forks::Super::MAX_PROC--; 
+            $Forks::Super::MAX_PROC ||= 1;
+            print STDERR "MAX_PROC changed to $Forks::Super::MAX_PROC\n";
+        } else {
+            print STDERR
+                "\$Forks::Super::MAX_PROC is a coderef. Unable to decrement\n"; 
+        }
     };
     $XSIG{$config_sig[4]}[1] = sub { Forks::Super::Debug::parent_dump(0); };
     $XSIG{$config_sig[5]}[1] = sub { Forks::Super::Debug::parent_dump(1); };
