@@ -6,7 +6,8 @@
 
 package Forks::Super::Job;
 use Forks::Super::Debug qw(debug);
-use Forks::Super::Util qw(is_number qualify_sub_name IS_CYGWIN IS_WIN32 is_pipe);
+use Forks::Super::Util qw(is_number qualify_sub_name
+                          IS_CYGWIN IS_WIN32 is_pipe);
 use Forks::Super::Config qw(:all);
 use Forks::Super::Job::Ipc;   # does windows prefer to load Ipc before Timeout?
 use Forks::Super::Job::Timeout;
@@ -25,13 +26,15 @@ use warnings;
 eval "use Devel::GlobalDestruction";
 
 our @ISA = qw(Exporter);
-our @EXPORT = qw(@ALL_JOBS %ALL_JOBS);
-our $VERSION = '0.76';
+our @EXPORT = qw(@ALL_JOBS %ALL_JOBS PREFORK POSTFORK 
+                 POSTFORK_PARENT POSTFORK_CHILD);
+our $VERSION = '0.77';
 
 our (@ALL_JOBS, %ALL_JOBS, @ARCHIVED_JOBS, $WIN32_PROC, $WIN32_PROC_PID);
 our $OVERLOAD_ENABLED = 0;
 our $INSIDE_END_QUEUE = 0;
 our $_RETRY_PAUSE;
+our (@PREFORK, @POSTFORK_PARENT, @POSTFORK_CHILD);
 
 # a reference to the Job that launched a process.
 # should only by set in the _child_ process created by a Job
@@ -345,7 +348,8 @@ sub _can_launch_delayed_start_check {
 sub _can_launch_dependency_check {
     my $job = shift;
     my @dep_on = defined($job->{depend_on}) ? @{$job->{depend_on}} : ();
-    my @dep_start = defined($job->{depend_start}) ? @{$job->{depend_start}} : ();
+    my @dep_start = defined($job->{depend_start}) 
+        ? @{$job->{depend_start}} : ();
 
     foreach my $dj (@dep_on) {
 	my $j = $ALL_JOBS{$dj};
@@ -410,10 +414,7 @@ sub _can_launch_remote {
 
 sub _can_launch_remote_check_host {
     my ($job, $h) = @_;
-    my $max_proc = 
-        defined $job->{max_proc}           ? $job->{max_proc} :
-        exists $Forks::Super::MAX_PROC{$h} ? $Forks::Super::MAX_PROC{$h} :
-        defined $Forks::Super::MAX_PROC    ? $Forks::Super::MAX_PROC : 0;
+    my $max_proc = $job->max_proc($h);
     if ($max_proc < 1) {
         debug("_can_launch_remote: no restriction on host $h")
             if $job->{debug};
@@ -431,13 +432,32 @@ sub _can_launch_remote_check_host {
     } 
 }
 
-sub _max_proc {
-    my $j = shift;
-    $j->{max_proc} ||= $j->{max_fork};
-    return defined($j->{max_proc}) ? $j->{max_proc} : $Forks::Super::MAX_PROC;
+sub max_proc {
+    my $val;
+    if (@_ > 0 && ref($_[0]) eq 'Forks::Super::Job'
+        && (defined($_[0]->{max_proc}) || defined($_[0]->{max_fork}))) {
+        $val = $_[0]->{max_proc} || $_[0]->{max_fork};
+    } else {
+        $val = $Forks::Super::MAX_PROC;
+        my $host = shift;
+        if (defined($host)) {
+            if (defined($Forks::Super::MAX_PROC{$host})) {
+                $val = $Forks::Super::MAX_PROC{$host};
+            } elsif (defined($Forks::Super::MAX_PROC{DEFAULT})) {
+                $val = $Forks::Super::MAX_PROC{DEFAULT};
+            }
+        }
+    }
+    return ref($val) eq 'CODE' ? $val->() : $val;
 }
 
-sub _max_load {
+sub _max_proc { # used in test suite but not in this distro itself
+    my $j = shift;
+    $j->{max_proc} ||= $j->{max_fork};
+    return defined($j->{max_proc}) ? $j->{max_proc} : max_proc();
+}
+
+sub _max_load { # used in test suite but not in this distro itself
     my $j = shift;
     return defined($j->{max_load}) ? $j->{max_load} : $Forks::Super::MAX_LOAD;
 }
@@ -470,8 +490,7 @@ sub _can_launch {
         }
     }
 
-    my $max_proc = defined($job->{max_proc})
-	? $job->{max_proc} : $Forks::Super::MAX_PROC;
+    my $max_proc = $job->max_proc();
     my $max_load = defined($job->{max_load})
 	? $job->{max_load} : $Forks::Super::MAX_LOAD;
     if ($max_proc > 0) {
@@ -530,7 +549,7 @@ sub launch {
     $job->{cwd} = &Cwd::getcwd;
 
 
-
+    $_->() for @PREFORK;
 
     my $pid = _robust_fork($job);
     if (!defined $pid) {
@@ -546,12 +565,16 @@ sub launch {
 
     if (Forks::Super::Util::isValidPid($pid)) {
 
+        $_->() for @POSTFORK_PARENT;
+
 	# parent
 	return _postlaunch_parent($pid, $job);
 
     } 
     if ($pid == 0) {
 
+        $_->() for @POSTFORK_CHILD;
+
 	$job->{real_pid} = $job->{pid} = "$$ child";
 	$job->{is_child} = 1;
 
@@ -1074,13 +1097,33 @@ sub _postlaunch_child_to_remote_cmd {
                 $host = $user;
                 $user = $remote->{user};
             }
+            if ($remote->{port}) {
+                $host .= ":" . $remote->{port};
+            }
             my $ssh = Net::SSH::Perl->new($host);
+
             if ($remote->{password}) {
                 my $login_ok = $ssh->login($user, $remote->{password}, 1);
-                print TTY "login: $login_ok\n";
-                # ...;
+                print TTY "login[1]: $login_ok\n";
+                if (!$login_ok) {
+                    # ...
+                }
             } else {
+                my $login_ok = $ssh->login($user, "", 1);
+                print TTY "login[2]: $login_ok\n";
+                if (!$login_ok) {
+                    # ...
+                }
             }
+
+            my $cmd = "@{$job->{cmd}}";
+            my $stdin;
+            if ($job->{stdin}) {
+                $stdin = $job->{stdin};
+            } elsif ($job->{fh_config}{in}) {
+                $stdin = join '', <STDIN>;
+            }
+
         } else {
             croak "Alternate ssh support for remote option not implemented";
         }
@@ -1950,8 +1993,8 @@ sub get {
 sub getByPid {
     my $id = shift;
     if (is_number($id)) {
-	my @j = grep { (defined($_->{pid}) && $_->{pid} == $id) ||
-		   (defined($_->{real_pid}) && $_->{real_pid} == $id)
+	my @j = grep { ($_->{pid} && ($_->{pid} == $id)) ||
+                       ($_->{real_pid} && ($_->{real_pid} == $id))
 		 } @ALL_JOBS;
 	return $j[0] if @j > 0;
     }
@@ -2076,8 +2119,8 @@ sub count_processes {
     my @filtered_active = @active;
     my @filtered_alive = @alive;
     if (defined $optional_pgid) {
-	@filtered_active = grep { $_->{pgid} == $optional_pgid } @filtered_active;
-	@filtered_alive = grep { $_->{pgid} == $optional_pgid } @filtered_alive;
+	@filtered_active = grep $_->{pgid} == $optional_pgid, @filtered_active;
+	@filtered_alive = grep $_->{pgid} == $optional_pgid, @filtered_alive;
     }
 
     my @n = (scalar(@filtered_active), scalar(@alive), 
@@ -2085,10 +2128,16 @@ sub count_processes {
 
     if ($Forks::Super::Debug::DEBUG) {
 	debug("count_processes(): @n");
-	debug('count_processes(): Filtered active: ',
-	      $filtered_active[0]->toString()) if $n[0];
-	debug('count_processes(): Alive: ', $alive[0]->toShortString()) if $n[1];
-	debug("count_processes(): Active: @active") if $n[2];
+        if ($n[0]) {
+            debug('count_processes(): Filtered active: ',
+                  $filtered_active[0]->toString());
+        }
+        if ($n[1]) {
+            debug('count_processes(): Alive: ', $alive[0]->toShortString());
+        }
+        if ($n[2]) {
+            debug("count_processes(): Active: @active");
+        }
     }
 
     return @n;
@@ -2178,6 +2227,23 @@ sub dispose {
     return;
 }
 
+sub PREFORK (&) {
+    push @PREFORK, $_[0];
+}
+
+sub POSTFORK (&) {
+    unshift @POSTFORK_PARENT, $_[0];
+    unshift @POSTFORK_CHILD, $_[0];
+}
+
+sub POSTFORK_CHILD (&) {
+    unshift @POSTFORK_CHILD, $_[0];
+}
+
+sub POSTFORK_PARENT (&) {
+    unshift @POSTFORK_PARENT, $_[0];
+}
+
 #
 # Print information about all known jobs to currently selected filehandle.
 #
@@ -2207,7 +2273,7 @@ Forks::Super::Job - object representing a background task
 
 =head1 VERSION
 
-0.76
+0.77
 
 =head1 SYNOPSIS
 
@@ -2891,7 +2957,8 @@ This method will
 
 =item * close any open filehandles
 
-=item * attempt to remove temporary files used for interprocess communication ]with the job
+=item * attempt to remove temporary files used for interprocess
+communication with the job
 
 =item * erase all information about the job
 
