@@ -18,7 +18,7 @@ use warnings;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(run_callback);
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
-our $VERSION = '0.76';
+our $VERSION = '0.77';
 
 sub run_callback {
     my ($job, $callback) = @_;
@@ -63,7 +63,8 @@ sub _preconfig_callbacks {
     }
     if (defined $job->{callback}{finish} && $job->{daemon}) {
 	carp 'Forks::Super::_preconfig_callbacks: ',
-              "'finish' callback is not going to be called with a daemon process";
+              "'finish' callback is not going to be called ",
+              "with a daemon process";
     }
     foreach my $callback_type (qw(finish start queue fail)) {
 	if (defined $job->{callback}{$callback_type}) {
