@@ -33,7 +33,7 @@ $| = 1;
 
 our @ISA = qw(Exporter);
 our @EXPORT = qw(close_fh);
-our $VERSION = '0.76';
+our $VERSION = '0.77';
 
 our (%FILENO, %SIG_OLD, $IPC_COUNT, $IPC_DIR_DEDICATED,
      @IPC_FILES, %IPC_FILES);
@@ -368,7 +368,8 @@ sub try_to_close_some_open_filehandles {
     #    * done (have a status)
 
     if ($nclosed) {
-	warn "Forks::Super::Job::Ipc: Closed $nclosed open file handles from jobs that look complete.\n";
+	warn "Forks::Super::Job::Ipc: Closed $nclosed open file handles ",
+             "from jobs that look complete.\n";
 	$__OPEN_FH -= $nclosed;
     } else {
         warn "Forks::Super::Job::Ipc: unable to close any open filehandles";
@@ -514,7 +515,8 @@ sub _preconfig_fh_parse_stdxxx {
 	} else {
 	    $config->{stdout} = $job->{stdout};
 	    $config->{out} = 1;
-	    $job->{'_callback_collect'} = \&Forks::Super::Job::Ipc::collect_output;
+	    $job->{'_callback_collect'} =
+                \&Forks::Super::Job::Ipc::collect_output;
 	}
     }
 
@@ -525,7 +527,8 @@ sub _preconfig_fh_parse_stdxxx {
 	} else {
 	    $config->{stderr} = $job->{stderr};
 	    $config->{err} = 1;
-	    $job->{'_callback_collect'} = \&Forks::Super::Job::Ipc::collect_output;
+	    $job->{'_callback_collect'} =
+                \&Forks::Super::Job::Ipc::collect_output;
 	}
     }
     return;
@@ -1023,7 +1026,7 @@ sub set_ipc_dir {
 	my $readme = "$_IPC_DIR/README.txt";
 	my $localtime1 = time;
 	my $localtime2 = scalar localtime;
-	if (open my $readme_fh, '>', $readme) {  ## no critic (ThisIsA,BriefOpen)
+	if (open my $readme_fh, '>', $readme) {
 	    print $readme_fh <<"____";
 This directory was created by $^O process $$ at
 $localtime2
@@ -1483,8 +1486,10 @@ sub _config_fh_parent_stdin {
 	    __config_fh_parent_stdin_file($job);
 	} else {
 	    # hope we don't / can't get here.
-	    Carp::cluck 'fh_config->{in} is specified for ', $job->toFullString(),
-		    "but we did not configure it in _config_fh_parent_stdin.\n";
+	    Carp::cluck 'fh_config->{in} is specified for ',
+                        $job->toFullString(),
+                        "but we did not configure it in ",
+                        "_config_fh_parent_stdin.\n";
 	}
     }
     if (defined $job->{child_stdin}) {
