@@ -14,7 +14,7 @@ use strict;
 use warnings;
 require Forks::Super::Job::OS::Win32 if &IS_WIN32 || &IS_CYGWIN;
 
-our $VERSION = '0.76';
+our $VERSION = '0.77';
 
 our $CPU_AFFINITY_CALLS = 0;
 our $OS_PRIORITY_CALLS = 0;
@@ -338,12 +338,18 @@ sub poor_mans_alarm {
     }
 
     # program to monitor a pid:
-    my $prog = "\$0='PMA($pid,$time)';sleep 1,kill(0,$pid)||exit for 1..$time;kill -9,$pid";
+    my $z = "PMA($pid,$time)";
+    my $prog = "\$0='$z';sleep 1,kill(0,$pid)||exit for 1..$time;kill -9,$pid";
+
+#   my ($p,$t) = ($pid,$time);
+#   my $prog = "\$0='PMA($p,$t)';sleep 1,kill(0,$p)||exit for 1..$t;kill -9,$p";
+
     if (&IS_WIN32) {
 	$prog .= ";system 'taskkill /f /pid $pid >nul'";
 	my $pma_pid = system 1, qq[$^X -e "$prog"];
 	if ($Forks::Super::Debug::DEBUG) {
-	    Forks::Super::Debug::DEBUG("set poor man's alarm for $pid/$time in process $pma_pid");
+	    Forks::Super::Debug::DEBUG(
+                "set poor man's alarm for $pid/$time in process $pma_pid");
 	}
 	return $pma_pid;
     } else {
