@@ -10,7 +10,7 @@ use Carp;
 use strict;
 use warnings;
 
-our $VERSION = '0.76';
+our $VERSION = '0.77';
 
 # "protocols" for serializing data and the methods used
 # to carry out the serialization
@@ -187,10 +187,10 @@ sub _fetch {
 		$self->{value} = [];
 	    } elsif (ref $self->{value} ne 'ARRAY') {
 
-		if ($self->{value} eq '') {
+		if (!length($self->{value})) {
 		    $self->{value} = [];
 		} else {
-		    $self->{value} = [];
+		    $self->{value} = [ $self->{value} ];
 		}
 	    }
 	    $self->{value_set} = 1;
@@ -212,7 +212,7 @@ Forks::Super::LazyEval::BackgroundArray
 
 =head1 VERSION
 
-0.76
+0.77
 
 =head1 DESCRIPTION
 
