@@ -33,7 +33,7 @@ sub STORE {
     if ($ATTR{''}) {
 	$VALUE{$self} = '';
     } else {
-	carp "Invalid assignment to enumerated tied scalar\n";
+	carp "Invalid assignment to enumerated tied scalar";
     }
     return;
 }
