@@ -16,7 +16,7 @@ use constant IS_CYGWIN => $^O =~ /cygwin/i;
 use constant IS_WIN32ish => &IS_WIN32 || &IS_CYGWIN;
 
 our @ISA = qw(Exporter);
-our $VERSION = '0.76';
+our $VERSION = '0.77';
 our @EXPORT_OK = qw(Ctime is_number isValidPid pause qualify_sub_name 
 		    is_socket is_pipe IS_WIN32 IS_CYGWIN okl);
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
@@ -57,20 +57,20 @@ sub Ctime {
 }
 
 sub is_number {
-    my $a = shift;
-    $a =~ s/^\s+//;
-    $a =~ s/\s+$//;
+    my $s = shift;
+    $s =~ s/^\s+//;
+    $s =~ s/\s+$//;
 
     # www.cpantesters.org/cpan/report/dda92dc8-663c-11e3-bd14-e3bee4621ba3:
     # "Out of memory during ridiculously large request". Does this mean
-    # that $a is too long?
-    if (length($a) > 100) {
-	return 0 if $a =~ /[^0-9eE.+-]/;
+    # that $s is too long?
+    if (length($s) > 100) {
+	return 0 if $s =~ /[^0-9eE.+-]/;
     }
 
     # from Scalar::Util::PP::looks_like_number:
-    return $a =~ /^ [+-]? [0-9]+ $/x ||
-	$a =~ /^ ([+-]?)
+    return $s =~ /^ [+-]? [0-9]+ $/x ||
+	$s =~ /^ ([+-]?)
                  (?=[0-9]|\.[0-9])
                  [0-9]*
                  (\.[0-9]*)?
@@ -366,7 +366,7 @@ Forks::Super::Util - utility routines for Forks::Super module
 
 =head1 VERSION
 
-0.76
+0.77
 
 =head1 SYNOPSIS
 
@@ -484,12 +484,12 @@ requested delay.
 The return value of this function is the estimated number of seconds
 that the function actually waited.
 
-=head2 $qualified_name = qualify_sub_name($unqualified_subroutine_name_or_code_reference)
+=head2 $qualified_name = qualify_sub_name($unqualified_sub_name_or_code_ref)
 
 Prepends a package qualifier from the current context, if necessary,
 from current execution context of a scalar subroutine name. Used when
-an unqualified subroutine name is passed in any L<Forks::Super> function argument
-that expects a code reference.
+an unqualified subroutine name is passed in any L<Forks::Super>
+function argument that expects a code reference.
 
     package Foo;
     sub do_something_in_background { ... }
